package ru.ulstu.extractor.ts.creator;

import org.springframework.stereotype.Component;
import ru.ulstu.extractor.commit.service.CommitService;
import ru.ulstu.extractor.gitrepository.service.GitRepositoryService;
import ru.ulstu.extractor.ts.model.TimeSeries;
import ru.ulstu.extractor.ts.model.TimeSeriesType;
import ru.ulstu.extractor.ts.model.TimeSeriesValue;
import ru.ulstu.extractor.ts.service.TimeSeriesService;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

@Component
public class CommitsTS extends AbstractTimeSeriesCreator {
    private final TimeSeriesService timeSeriesService;
    private final CommitService commitService;
    private final GitRepositoryService gitRepositoryService;

    public CommitsTS(TimeSeriesService timeSeriesService,
                     CommitService commitService,
                     GitRepositoryService gitRepositoryService) {
        this.timeSeriesService = timeSeriesService;
        this.commitService = commitService;
        this.gitRepositoryService = gitRepositoryService;
    }

    @Override
    public List<TimeSeries> getTimeSeries(Integer repositoryId, String branchName) {
        //TODO: добавить постраничное чтение
        return Collections.singletonList(
                new TimeSeries(
                        String.format("%s %s %s",
                                gitRepositoryService.findById(repositoryId).getName(),
                                branchName,
                                getTimeSeriesType().getDescription()),
                        getTimeSeriesType(),
                        commitService.findByRepositoryIdAndName(repositoryId, branchName)
                                .stream()
                                .map(c -> new TimeSeriesValue(c.getDate(), 1.0))
                                .collect(Collectors.toList())));
    }

    @Override
    public TimeSeriesService getTimeSeriesService() {
        return timeSeriesService;
    }

    @Override
    public TimeSeriesType getTimeSeriesType() {
        return TimeSeriesType.COMMITS;
    }
}
